/*
 * Copyright 2013 Canonical Ltd.
 *
 * This file is part of powerd.
 *
 * powerd is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * powerd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <stdio.h>
#include <errno.h>
#include <unistd.h>
#include <uuid/uuid.h>

#include "powerd-cli.h"

static int run_cmd_active(int argc, char *argv[])
{
    powerd_cookie_t cookie;

    if (argc != 1) {
        fprintf(stderr, "Error: %s takes no arguments\n", argv[0]);
        return -EINVAL;
    }

    requestSysState("active", POWERD_SYS_STATE_ACTIVE,&cookie);
    printf("Power State requested, cookie is %s.\nPress ctrl-c to exit.\n",
           cookie);

    pause();  /* wait for SIGINT */

    clearSysState(cookie);

    return 0;
}

const struct cli_cmd active_cmd = {
    .name = "active",
    .help_text = "Request the active state (i.e. prevent the system from suspending).",
    .run = run_cmd_active,
};

static int run_cmd_active_nc(int argc, char *argv[])
{
    powerd_cookie_t cookie;

    if (argc != 1) {
        fprintf(stderr, "Error: %s takes no arguments\n", argv[0]);
        return -EINVAL;
    }

    requestSysState("active-nc", POWERD_SYS_STATE_ACTIVE,&cookie);
    printf("Power State requested, cookie is %s\n", cookie);

    return 0;
}

const struct cli_cmd active_nc_cmd = {
    .name = "active-nc",
    .help_text = "Request the active state without clearing it. This is only "
                 "useful for testing powerd's automatic clean-up of orphaned "
                 "requests.",
    .run = run_cmd_active_nc,
};

static int run_cmd_clear_sys(int argc, char *argv[])
{
    char *arg;
    uuid_t uuid;

    if (argc != 2) {
        /* XXX: Usage */
        return -EINVAL;
    }
    arg = argv[1];

    if (uuid_parse(arg, uuid)) {
        fprintf(stderr, "Error: %s is not a valid cookie\n", arg);
        return -EINVAL;
    }

    clearSysState(arg);
    return 0;
}

const struct cli_cmd clear_sys_cmd = {
    .name = "clear-sys",
    .help_text = "",
    .run = run_cmd_clear_sys,
};
