
/*
 * Copyright 2013 Canonical Ltd.
 *
 * This file is part of powerd.
 *
 * powerd is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * powerd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <uuid/uuid.h>

#include "powerd-cli.h"

/*
 * Parse command line arguments to build a display request. Caller
 * must enure that argc > 1.
 */
static int build_display_request(char **argv, int argc,
                                 struct PublicDispRequest *pdr)
{
    int i;

    if (!strcasecmp(argv[1],"on")) {
        pdr->state = POWERD_DISPLAY_STATE_ON;
        cli_debug("Requesting Display On");
    } else if (!strcasecmp(argv[2],"dc")) {
        pdr->state = POWERD_DISPLAY_STATE_DONT_CARE;
        cli_debug("Requesting Display Don't Care");
    } else {
        return -EINVAL;
    }

    pdr->flags = 0;
    for (i = 2; i < argc; i++) {
        if (!strcmp(argv[i],"proximity")) {
            pdr->flags |= POWERD_DISPLAY_FLAG_USE_PROXIMITY;
            cli_debug("Requesting Proximity Sensor Enabled");
        }
        else if (!strcmp(argv[i],"disableab")) {
            pdr->flags |= POWERD_DISPLAY_FLAG_DISABLE_AUTOBRIGHTNESS;
            cli_debug("Requesting Proximity Disable AutoBrightness");
        }
        else if (!strcasecmp(argv[i],"bright")) {
            pdr->flags |= POWERD_DISPLAY_FLAG_BRIGHT;
            cli_debug("Requesting Bright");
        } else {
            /* Invalid argument */
            return -EINVAL;
        }
    }

    return 0;
}

static int run_cmd_display(int argc, char *argv[])
{
    struct PublicDispRequest pdr;
    powerd_cookie_t cookie;

    if (argc < 2) {
        /* XXX: Usage */
        return -EINVAL;
    }

    if (build_display_request(argv, argc, &pdr) == FALSE) {
        /* XXX: Usage */
        return -EINVAL;
    }

    requestDisplayState(pdr, "disp-test", &cookie);
    printf("Display State requested, cookie is %s.\n", cookie);
    printf("Press ctrl-c to exit.\n");

    pause();  /* wait for SIGINT */

    clearDisplayState(cookie);

    return 0;
}

const struct cli_cmd display_cmd = {
    .name = "display",
    .help_text = "",
    .run = run_cmd_display,
};

static int run_cmd_clear_disp(int argc, char *argv[])
{
    char *arg;
    uuid_t uuid;

    if (argc != 2) {
        /* XXX: Usage */
        return -EINVAL;
    }
    arg = argv[1];

    if (!uuid_parse(arg, uuid)==0) {
        fprintf(stderr, "Error: %s is not a valid cookie\n", arg);
        return -EINVAL;
    }

    clearDisplayState(arg);
    return 0;
}

const struct cli_cmd clear_disp_cmd = {
    .name = "clear-disp",
    .help_text = "",
    .run = run_cmd_clear_disp,
};
