/*
 * Copyright 2013 Canonical Ltd.
 *
 * This file is part of powerd.
 *
 * powerd is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * powerd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <stdio.h>
#include <errno.h>
#include <glib.h>

#include "powerd-cli.h"

static void print_sys_requests(GArray *requests)
{
    int i;
    struct PublicSysRequest *psr;

    printf("System State Requests:\n");
    if (requests->len == 0) {
        printf("  None\n");
    } else {
        for (i = 0; i < requests->len; i++) {
            psr = &g_array_index(requests, struct PublicSysRequest, i);
            printf("  Name: %s, Owner: %s, State: %d\n", psr->name,
                   psr->owner, psr->state);
        }
    }
}

static void print_display_requests(GArray *requests)
{
    int i;
    struct PublicDispRequest *pdr;

    printf("Display State Requests:\n");
    if (requests->len == 0) {
        printf("  None\n");
    } else {
        for (i = 0; i < requests->len; i++) {
            pdr = &g_array_index(requests, struct PublicDispRequest, i);
            printf("  Name: %s, Owner: %s, State: %d, Flags: %#08x\n",
                   pdr->name, pdr->owner, pdr->state, pdr->flags);
        }
    }
}

static int run_list(int argc, char *argv[])
{
    GArray *requests;

    if (argc != 1) {
        /* XXX: Usage */
        return -EINVAL;
    }

    requests = listSysRequests();
    print_sys_requests(requests);
    g_array_free(requests, TRUE);

    requests = listDisplayRequests();
    print_display_requests(requests);
    g_array_free(requests, TRUE);

    return 0;
}

const struct cli_cmd list_cmd = {
    .name = "list",
    .help_text = "List current system and display state requests.",
    .run = run_list,
};
