/*
 * Copyright 2013 Canonical Ltd.
 *
 * This file is part of powerd.
 *
 * powerd is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * powerd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>

#include "powerd-cli.h"

static GMainLoop *main_loop;

static void sig_handler(int signum)
{
    g_main_loop_quit(main_loop);
}

static void on_powerd_signal(GDBusProxy *proxy, gchar *sender_name,
                             gchar *signal_name, GVariant *parameters,
                             gpointer user_data)
{
    int system_state;
    int display_state;
    guint32 display_flags;

    if (!strcmp(signal_name,"SysPowerStateChange")) {
        g_variant_get(parameters, "(i)", &system_state);
        printf("Received %s: state=%d\n", signal_name, system_state);
    }
    else if (!strcmp(signal_name,"DisplayPowerStateChange")) {
        g_variant_get(parameters, "(iu)", &display_state, &display_flags);
        printf("Received %s: state=%d flags=%#08x\n",
            signal_name, display_state, display_flags);
    }
    else {
        cli_debug("Unknown signal from %s: %s", sender_name, signal_name);
    }
}

static void listen_for_signals(GDBusProxy *proxy)
{
    main_loop = g_main_loop_new (NULL, FALSE);
    g_signal_connect(proxy, "g-signal", G_CALLBACK (on_powerd_signal), NULL);

    signal(SIGINT, sig_handler);

    printf("Waiting for events, press ctrl-c to quit\n");
    g_main_loop_run(main_loop);

    g_main_loop_unref(main_loop);
}

static int run_listen(int argc, char *argv[])
{
    GDBusProxy *proxy;

    if (argc != 1) {
        /* XXX: Usage */
        return -EINVAL;
    }

    proxy = cli_get_dbus_proxy();
    if (!proxy) {
        fprintf(stderr, "Error: Could not get dbus proxy\n");
        return -EIO;
    }

    listen_for_signals(proxy);

    return 0;
}

const struct cli_cmd listen_cmd = {
    .name = "listen",
    .help_text = "",
    .run = run_listen,
};
